@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '1.03';
+$VERSION = '1.04';
 
 #----------------------------------------------------------------------------
 
@@ -177,6 +177,14 @@ here steals from Tony's module.
 
 See L<Games::Boggle> if you want a traditional Boggle rules module.
 
+=head1 DSLIP
+
+  R - Released
+  d - Developer
+  p - Perl only
+  O - Object oriented
+  p - Standard Perl
+
 =head1 AUTHOR
 
   Barbie, <barbie@cpan.org>
